"use client";

import { SimpleGrid, Icon, useColorModeValue } from "@chakra-ui/react";
import MiniStatistics from "@/components/card/MiniStatistics";
import { MdGroup } from "react-icons/md";
import { TbUsersGroup } from "react-icons/tb";
import IconBox from "components/icons/IconBox";
import { IoBriefcaseSharp } from "react-icons/io5";
import { FaUsers } from "react-icons/fa6";
import { BsFillPeopleFill, BsPersonBadge } from "react-icons/bs";

interface DashboardData {
  total_cases: number;
  total_agents: number;
  total_attendance: number;
  daily_assignment: number;
  daily_kyc: number;
  daily_consumer: number;
}

const StatsGrid = ({ dashboardData }: { dashboardData: DashboardData }) => {
  const boxBg = useColorModeValue("secondaryGray.300", "whiteAlpha.100");
  const brandColor = useColorModeValue("brand.500", "white");

  return (
    <SimpleGrid columns={{ base: 1, md: 2, lg: 3, "2xl": 3 }} gap="20px" mb="20px">
      <MiniStatistics
        startContent={<IconBox w="56px" h="56px" bg={boxBg} icon={<Icon w="32px" h="32px" as={IoBriefcaseSharp} color={brandColor} />} />}
        name="Total Cases"
        value={dashboardData.total_cases || "0"}
      />
      <MiniStatistics
        startContent={<IconBox w="56px" h="56px" bg={boxBg} icon={<Icon w="32px" h="32px" as={MdGroup} color={brandColor} />} />}
        name="Total Agents"
        value={dashboardData.total_agents || "0"}
      />
      <MiniStatistics
        startContent={<IconBox w="56px" h="56px" bg={boxBg} icon={<Icon w="32px" h="32px" as={TbUsersGroup} color={brandColor} />} />}
        name="Total Attendance"
        value={dashboardData.total_attendance || "0"}
      />
      <MiniStatistics
        startContent={<IconBox w="56px" h="56px" bg={boxBg} icon={<Icon w="28px" h="28px" as={FaUsers} color={brandColor} />} />}
        name="Daily Assignments"
        value={dashboardData.daily_assignment || "0"}
      />
      <MiniStatistics
        startContent={<IconBox w="56px" h="56px" bg={boxBg} icon={<Icon w="32px" h="32px" as={BsPersonBadge} color={brandColor} />} />}
        name="Daily Kycs"
        value={dashboardData.daily_kyc || "0"}
      />
      <MiniStatistics
        startContent={<IconBox w="56px" h="56px" bg={boxBg} icon={<Icon w="32px" h="32px" as={BsFillPeopleFill} color={brandColor} />} />}
        name="Daily Consumers"
        value={dashboardData.daily_consumer || "0"}
      />
    </SimpleGrid>
  );
};

export default StatsGrid;
